import React, { useRef, useState } from "react";
import {
  AddIcon,
  RemoveIcon,
  ResizeHeightIcon,
} from "../../../../../icons/ExportCommonIcons";
import LabledDropdown from "../../../../../ui/inputs/LabledDropdown";
import RenameInput from "../../../../../ui/inputs/RenameInput";
import { handleResize } from "../../../../../../functions/handleResizePannel";

const Trigger: React.FC = () => {
  // State to hold the list of triggers
  const [triggers, setTriggers] = useState<string[]>(["Trigger 1"]);
  const [selectedTrigger, setSelectedTrigger] = useState<string>("Trigger 1");
  const [activeOption, setActiveOption] = useState("onComplete");
  const triggersContainerRef = useRef<HTMLDivElement>(null);

  // States for dropdowns
  const [triggeredModel, setTriggeredModel] = useState<string[]>([]);
  const [triggeredPoint, setTriggeredPoint] = useState<string[]>([]);
  const [triggeredAction, setTriggeredAction] = useState<string[]>([]);

  // Function to handle adding a new trigger
  const addTrigger = (): void => {
    const newTrigger = `Trigger ${triggers.length + 1}`;
    setTriggers([...triggers, newTrigger]); // Add new trigger to the state

    // Initialize the states for the new trigger
    setTriggeredModel([...triggeredModel, ""]);
    setTriggeredPoint([...triggeredPoint, ""]);
    setTriggeredAction([...triggeredAction, ""]);
  };

  // Function to handle removing a trigger
  const removeTrigger = (index: number): void => {
    setTriggers(triggers.filter((_, i) => i !== index)); // Remove trigger by index
    setTriggeredModel(triggeredModel.filter((_, i) => i !== index));
    setTriggeredPoint(triggeredPoint.filter((_, i) => i !== index));
    setTriggeredAction(triggeredAction.filter((_, i) => i !== index));
  };

  return (
    <div className="trigger-wrapper">
      <div className="header">
        <div className="title">Trigger</div>
        <button
          className="add-button"
          onClick={addTrigger}
          style={{ cursor: "pointer" }}
        >
          <AddIcon /> Add
        </button>
      </div>
      <div className="trigger-list">
        <div
          className="lists-main-container"
          ref={triggersContainerRef}
          style={{ height: "120px" }}
        >
          <div className="list-container">
            {triggers.map((trigger: any, index: number) => (
              <div
                key={index}
                className={`list-item ${
                  selectedTrigger === trigger ? "active" : ""
                }`}
                onClick={() => setSelectedTrigger(trigger)}
              >
                <button className="value" onClick={() => {}}>
                  <RenameInput value={trigger} onRename={() => {}} />
                </button>
                {triggers.length > 1 && (
                  <button
                    className="remove-button"
                    onClick={() => removeTrigger(index)}
                  >
                    <RemoveIcon />
                  </button>
                )}
              </div>
            ))}
          </div>
          <button
            className="resize-icon"
            id="action-resize"
            onMouseDown={(e: any) => handleResize(e, triggersContainerRef)}
          >
            <ResizeHeightIcon />
          </button>
        </div>
        <div className="trigger-item">
          <div className="trigger-name">{selectedTrigger}</div>
          <LabledDropdown
            label="Trigger on"
            defaultOption={activeOption}
            options={["onComplete", "onStart", "onStop", "delay"]}
            onSelect={(option) => setActiveOption(option)}
          />
          <div className="trigger-options">
            <LabledDropdown
              label="Triggered Object"
              defaultOption={triggeredModel[0] || "Select Model"}
              options={["Model 1", "Model 2", "Model 3"]}
              onSelect={(option) => {
                const newModel = [...triggeredModel];
                newModel[0] = option;
                setTriggeredModel(newModel);
              }}
            />
            <LabledDropdown
              label="Triggered Point"
              defaultOption={triggeredPoint[0] || "Select Point"}
              options={["Point 1", "Point 2", "Point 3"]}
              onSelect={(option) => {
                const newPoint = [...triggeredPoint];
                newPoint[0] = option;
                setTriggeredPoint(newPoint);
              }}
            />
            <LabledDropdown
              label="Triggered Action"
              defaultOption={triggeredAction[0] || "Select Action"}
              options={["Action 1", "Action 2", "Action 3"]}
              onSelect={(option) => {
                const newAction = [...triggeredAction];
                newAction[0] = option;
                setTriggeredAction(newAction);
              }}
            />
          </div>
        </div>
      </div>
    </div>
  );
};

export default Trigger;
