import { useMemo } from "react";
import { Canvas } from "@react-three/fiber";
import { KeyboardControls } from "@react-three/drei";

import Builder from "../builder/builder";
import Visualization from "../visualization/visualization";
import Setup from "./setup/setup";
import Simulation from "../simulation/simulation";
import Collaboration from "../collaboration/collaboration";

export default function Scene() {
  const map = useMemo(
    () => [
      { name: "forward", keys: ["ArrowUp", "w", "W"] },
      { name: "backward", keys: ["ArrowDown", "s", "S"] },
      { name: "left", keys: ["ArrowLeft", "a", "A"] },
      { name: "right", keys: ["ArrowRight", "d", "D"] },
    ],
    []
  );

  return (
      <KeyboardControls map={map}>
        <Canvas
          eventPrefix="client"
          gl={{ powerPreference: "high-performance", antialias: true }}
          onContextMenu={(e) => {
            e.preventDefault();
          }}
        >
          <Setup />

          <Collaboration />

          <Builder />

          <Simulation />

          <Visualization />
        </Canvas>
      </KeyboardControls>
  );
}
