import React, { useRef } from "react";
import * as THREE from "three";
import { ThreeEvent } from "@react-three/fiber";

interface PickDropProps {
  position: number[];
  modelUuid: string;
  pointUuid: string;
  actionType: "pick" | "drop";
  actionUuid: string;
  gltfScene: THREE.Group;
  selectedPoint: THREE.Mesh | null;
  handlePointerDown: (e: ThreeEvent<PointerEvent>) => void;
  isSelected: boolean;
}

const PickDropPoints: React.FC<PickDropProps> = ({
  position,
  modelUuid,
  pointUuid,
  actionType,
  actionUuid,
  gltfScene,
  selectedPoint,
  handlePointerDown,
  isSelected,
}) => {
  const groupRef = useRef<THREE.Group>(null);

  return (
    <group
      ref={groupRef}
      position={
        Array.isArray(position) && position.length === 3
          ? new THREE.Vector3(...position)
          : new THREE.Vector3(0, 0, 0)
      }
      onPointerDown={(e) => {
        e.stopPropagation(); // Important to prevent event bubbling
        if (!isSelected) return;
        handlePointerDown(e);
      }}
      userData={{ modelUuid, pointUuid, actionType, actionUuid }}
    >
      <primitive
        object={gltfScene.clone()}
        position={[0, 0, 0]} // Ensure this stays at origin
        scale={[0.5, 0.5, 0.5]}
      />
    </group>
  );
};

export default PickDropPoints;
